@@ -96,21 +96,6 @@ def fis_bs_pareto_graph(variable, title_show = False, salida='grafico'):
     else:
         return (pareto)
 
-def fis_tool_clean_df_columns(df):
-    for col in df.columns:
-        new_col = col.lower()
-        new_col = new_col.replace(" ", "_")
-        new_col = new_col.replace("ó", "o").replace("ò","o")
-        new_col = new_col.replace("í", "i").replace("á", "a").replace("é", "e")
-        new_col = new_col.replace("ü", "u").replace("à","a").replace("è","e")
-        new_col = new_col.replace("(", "")
-        new_col = new_col.replace(")", "")
-        new_col = new_col.replace("-", "")
-        new_col = new_col.replace('º', "").replace("__", "_")
-        new_col = new_col.replace("ñ", "n").replace("ú", "u").replace("í", "i")
-        df.rename({col: new_col}, axis=1, inplace=True)
-    return df
-
 def fis_bs_histogram(df,value,labelx=None,labely=None,figsize=(11,7),dpi=85):
     f = plt.figure(figsize=figsize,dpi=dpi)
     ax = sns.histplot(df,x=value,shrink=0.8)
