@@ -88,4 +88,33 @@ def fis_tools_quitar_tildes(palabra):
     #Creamos un traductor
     traductor = str.maketrans(con,sin)
     #Aplicamos el traductor y devolvemos la palabra limpia
-    return(palabra.translate(traductor))
\ No newline at end of file
+    return(palabra.translate(traductor))
+    
+def fis_tools_strong_corr(df, lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
+    #Calcula la matriz de correlación
+    c = x.corr().abs()
+    #Lo pasa todo a filas
+    c= c.unstack()
+    #Pasa el índice a columnas y le pone nombres
+    c = pd.DataFrame(c).reset_index()
+    c.columns = ['var1','var2','corr']
+    #A dataframe, filtra limites y ordena en descendiente
+    c = c.loc[(c['corr'] > lim_inf) &  (c['corr'] < lim_sup),:].sort_values(by = 'corr', ascending=False)
+    #Desduplica las correlaciones (o no si drop_dupli es False)
+    c = c if drop_dupli == False else c.drop_duplicates(subset = ['corr'])
+    #Devuelve la salida
+    return(c)
+    
+def fis_tools_ranking_mi(mutual_selector, modo = 'tabla'):
+    #Maqueta el ranking
+    ranking_mi = pd.DataFrame(mutual_selector, index = x.columns).reset_index()
+    ranking_mi.columns = ['variable','importancia_mi']
+    ranking_mi = ranking_mi.sort_values(by = 'importancia_mi', ascending = False)
+    ranking_mi['ranking_mi'] = np.arange(0,ranking_mi.shape[0])
+    #Muestra la salida
+    if modo == 'tabla':
+        return(ranking_mi)
+    else:
+        g = ranking_mi[0:15].importancia_mi.sort_values().plot.barh()
+        g.set_yticklabels(ranking_mi[0:15].sort_values(by = 'importancia_mi').variable)
+        return(g)
\ No newline at end of file
